This is the basic namespace to use in unit tests. It provides various functions that can be used to simulate a MonkeyCI build environment.
This is the basic namespace to use in unit tests. It provides various functions that can be used to simulate a MonkeyCI build environment.
(added files)Defines a set of added (i.e. new) files. To be used with the xxx-changes functions.
Defines a set of added (i.e. new) files. To be used with the `xxx-changes` functions.
Retrieves configured checkout dir in the context
Retrieves configured checkout dir in the context
(execute-job job ctx)Executes given job with specified context. Look out for side effects!
Executes given job with specified context. Look out for side effects!
(modified files)Defines a set of modified files.
Defines a set of modified files.
(removed files)Defines a set of removed files.
Defines a set of removed files.
(resolve-jobs jobs ctx)Given one or more unresolved jobs, resolves them using the given context. This is useful if you want to get a full list of the actual jobs that MonkeyCI will run given a specific context.
Given one or more unresolved jobs, resolves them using the given context. This is useful if you want to get a full list of the actual jobs that MonkeyCI will run given a specific context.
(set-changes ctx changes)Overwrites context file changes
Overwrites context file changes
Basic test context, to use in test jobs
Basic test context, to use in test jobs
(update-changes ctx f & args)Updates context file changes
Updates context file changes
(with-build-params params & body)Simulates given build parameters for the body to execute
Simulates given build parameters for the body to execute
(with-build-params* params f)(with-changes ctx changes)Adds given file set to the context file changes
Adds given file set to the context file changes
(with-checkout-dir ctx dir)Sets the given directory as the build checkout dir in the context
Sets the given directory as the build checkout dir in the context
(with-git-ref ctx ref)Sets given ref in the context git configuration
Sets given ref in the context git configuration
(with-tmp-checkout-dir ctx)Configures a temporary checkout directory in the context
Configures a temporary checkout directory in the context
(with-tmp-dir dir & body)(with-tmp-dir* f)Creates a temp dir, then invokes f on it
Creates a temp dir, then invokes `f` on it
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |