This is the basic namespace to use in unit tests. It provides various functions that can be used to simulate a MonkeyCI build environment.
This is the basic namespace to use in unit tests. It provides various functions that can be used to simulate a MonkeyCI build environment.
(added files)Defines a set of added (i.e. new) files. To be used with the xxx-changes functions.
Defines a set of added (i.e. new) files. To be used with the `xxx-changes` functions.
(modified files)Defines a set of modified files.
Defines a set of modified files.
(removed files)Defines a set of removed files.
Defines a set of removed files.
(set-changes ctx changes)Overwrites context file changes
Overwrites context file changes
Basic test context, to use in test jobs
Basic test context, to use in test jobs
(update-changes ctx f & args)Updates context file changes
Updates context file changes
(with-build-params params & body)Simulates given build parameters for the body to execute
Simulates given build parameters for the body to execute
(with-build-params* params f)(with-changes ctx changes)Adds given file set to the context file changes
Adds given file set to the context file changes
(with-git-ref ctx ref)Sets given ref in the context git configuration
Sets given ref in the context git configuration
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |